@@ -6,6 +6,6 @@ import logging
 logging.basicConfig(format='[%(levelname)s] %(message)s', level=logging.WARNING)
 
 try:
-    app()
+    app(prog_name="dsnap")
 except (NoCredentialsError, NoRegionError) as e:
     logging.error(e.args[0])
